@@ -31,6 +31,7 @@
 #include "config.h"
 #include "common.h"
 #include "lib.h"
+#include "both.h"
 
 char *xstrcat3save(const char *a, const char *b, const char *c) {
   char *r;
@@ -42,14 +43,6 @@ char *xstrcat3save(const char *a, const char *b, const char *c) {
   return r;
 }
 
-char *xstrsave(const char *s) {
-  char *r;
-
-  r= xmalloc(strlen(s)+1);
-  strcpy(r,s);
-  return r;
-}
-
 char *xstrsubsave(const char *begin, int len) {
   char *r;
   
@@ -59,17 +52,6 @@ char *xstrsubsave(const char *begin, int len) {
   return r;
 }
 
-void *xmalloc(size_t s) {
-  void *p;
-  p= malloc(s?s:1); if (!p) syscallerror("malloc");
-  return p;
-}
-
-void *xrealloc(void *p, size_t s) {
-  p= realloc(p,s); if (!p) syscallerror("realloc");
-  return p;
-}
-
 int makeroom(char **buffer, int *size, int needed) {
   if (needed > MAX_GENERAL_STRING) return -1;
   if (*size >= needed) return 0;
